# coding=utf8
""" Errors

Mouth error codes
"""

__author__ = "Chris Nasr"
__copyright__ = "Ouroboros Coding Inc"
__version__ = "1.0.0"
__email__ = "chris@ouroboroscoding.com"
__created__ = "2023-01-11"

TEMPLATE_CONTENT_ERROR = 1300
ATTACHMENT_STRUCTURE = 1301
ATTACHMENT_DECODE = 1302
SMTP_ERROR = 1303
